// src/frontend/concrete_simulation.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef CONCRETE_SIMULATION_HH
#define CONCRETE_SIMULATION_HH 1

#include "config.h"

#include "simulation.hh"
#include "concrete_history.hh"

#include <map>
#include <stdexcept>
#include <utility>
#include <vector>

namespace sgpem
{
  class ConcreteSimulation;

  class ConcreteSimulation : public Simulation
  {
  public:
    ConcreteSimulation();

    void  run() throw(UserInterruptException, NullPolicyException, MalformedPolicyException);

    void  pause();

		void jump_to(History::position p) throw(UserInterruptException, NullPolicyException, MalformedPolicyException);

    void  stop();

		bool step() throw(UserInterruptException, NullPolicyException, MalformedPolicyException);

    void  set_mode(mode new_mode);

    mode  get_mode() const;

    state get_state() const;

    /**
     \throw An instance of CPUPolicyException, \b not a derived class!!!
     */
    void set_policy(CPUPolicy*) throw(CPUPolicyException);

    void set_resource_policy(ResourcePolicy*);

    ConcreteHistory& get_history();

		const ConcreteHistory& get_history() const;

    CPUPolicy* get_policy();
    ResourcePolicy * get_resource_policy();


  private:
    state  _state;
    mode   _mode;
    ConcreteHistory _history;
    CPUPolicy* _policy;
    ResourcePolicy* _resource_policy;
  };

}


#endif

