// src/backend/default_resource_policy_manager.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef DEFAULT_RESOURCE_POLICY_MANAGER_HH
#define DEFAULT_RESOURCE_POLICY_MANAGER_HH 1

namespace sgpem
{
  class ResourcePolicy;
}

#include "config.h"

#include "resource_policy_manager.hh"

#include <vector>


namespace sgpem
{
  class DefaultResourcePolicyManager;

  /**
    ResourcePolicyManager is the Abstract Factory for \ref ResourcePolicy objects.
  */
  class SG_DLLEXPORT DefaultResourcePolicyManager : public ResourcePolicyManager
  {
  public:
    /** \brief DefaultResourcePolicyManager constructor
     *
     * Registers itself to the ResourcePoliciesGatekeeper singleton.
    */
    DefaultResourcePolicyManager();

    virtual ~DefaultResourcePolicyManager();

    virtual const std::vector<ResourcePolicy*>& get_avail_policies() const;

  private:
    std::vector<ResourcePolicy*> _policies;

    // an Instance of this class is created by default and it is registered to
    // the ResourcePolicyGateKeeper
    static DefaultResourcePolicyManager _default_instance;
  };

} //~ namespace sgpem

#endif

